@@ -1,6 +1,5 @@
 
 ###############################################################################
-context("testing package installation")
 test_that("testing package installation", {
   expect_identical(check_load_packages("config"), 0)
   expect_identical(check_load_packages("valueEQ5D"), 0)
@@ -11,17 +10,15 @@ test_that("testing package installation", {
   expect_identical(check_load_packages(reqd_packages), 0)
 })
 ##############################################################################
-context("testing file existence")
 test_that("test for file existence and access", {
   thisfile <- system.file("extdata", "blank.txt",
-    package = "IPDFileCheck"
+                          package = "IPDFileCheck"
   )
   expect_identical(test_file_exist_read(thisfile), 0)
-  nofile <- system.file("extdata", "read.txt", package = "IPDFileCheck")
-  expect_identical(test_file_exist_read(nofile), -2)
+  #nofile <- system.file("extdata", "read.txt", package = "IPDFileCheck")
+  #expect_identical(test_file_exist_read(nofile), -2)
 })
 # #############################################################################
-context("testing column names of a data")
 test_that("testing column names of a data", {
   x <- c("F", "M", "cvb", "sheeja")
   y <- c(1, 2, 3, 4)
@@ -31,8 +28,7 @@ test_that("testing column names of a data", {
   colnames(tempdata) <- c("num", "sex")
   expect_identical(test_columnnames(c("num", "name"), tempdata), -1)
 })
-# #########################################################################
-context("testing age calculated from year of birth")
+# #####################################################
 test_that("testing age calculated from year of birth", {
   x <- c("1957", "1987", 0, "1989")
   y <- c(1, 2, 3, 4)
@@ -43,7 +39,7 @@ test_that("testing age calculated from year of birth", {
   ag3 <- as.numeric(format(Sys.Date(), "%Y")) - 1989
   ages <- c(ag1, ag2, 0, ag3)
   mod_data <- calculate_age_from_year(tempdata, "dob", NULL, 0)$calc.age.yob
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
 
   x <- c("1957", "1987", 0, "1989")
@@ -55,7 +51,7 @@ test_that("testing age calculated from year of birth", {
   ag3 <- as.numeric(format(Sys.Date(), "%Y")) - 1989
   ages <- c(ag1, ag2, 0, ag3)
   mod_data <- calculate_age_from_year(tempdata, "dob", NA, 0)$calc.age.yob
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("1957", "1987", 0, "1989")
   y <- c(1, 2, 3, 4)
@@ -65,7 +61,7 @@ test_that("testing age calculated from year of birth", {
   ages <- c(30, 10, 0, 20)
   mod_data <- calculate_age_from_year(tempdata, "dob",
                                       "enddate", 0)$calc.age.yob
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   y2 <- c("sh", "sh", 0, "sh")
   tempdata <- as.data.frame(cbind(y, x, y2))
@@ -80,28 +76,27 @@ test_that("testing age calculated from year of birth", {
   colnames(tempdata) <- c("name", "dob")
   ages <- c(ag1, ag2, NA, ag3)
   mod_data <- calculate_age_from_year(tempdata, "dob", NULL, NA)$calc.age.yob
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
   x <- c(1957, 1987, NA, 1989)
   y <- c(1, 2, 3, 4)
   tempdata <- as.data.frame(cbind(y, x))
   colnames(tempdata) <- c("name", "dob")
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
   colnames(tempdata) <- c("name", "date")
   expect_error(calculate_age_from_year(tempdata, "dob", NULL, NA),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
   x <- c(1957, 1987, 1800, 1989)
   y <- c(1, 2, 3, 4)
   tempdata <- as.data.frame(cbind(y, x))
   colnames(tempdata) <- c("name", "dob")
   expect_error(calculate_age_from_year(tempdata, "dob", NULL, NA),
-    "Age can not be negative OR greater than 150",
-    fixed = TRUE
+               "Age can not be negative OR greater than 150",
+               fixed = TRUE
   )
 })
 # ############################################################################
-context("testing age")
 test_that("test for age checks for valid age", {
   x <- c(0, 11, NA, 120)
   y <- c(1, 2, 3, 4)
@@ -135,8 +130,8 @@ test_that("test for age checks for valid age", {
 
   colnames(tempdata) <- c("name", "sex")
   expect_error((test_age(tempdata, "age", -99)),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
 
   x <- c(0, 11.5, "", 120, "noresponse")
@@ -150,8 +145,8 @@ test_that("test for age checks for valid age", {
   tempdata <- as.data.frame(cbind(y, x), stringsAsFactors = F)
   colnames(tempdata) <- c("name", "age")
   expect_error((test_age(tempdata, "years", "noresponse")),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
 
   x <- c(0, 11.5, "sh", 120, "noresponse")
@@ -161,7 +156,6 @@ test_that("test for age checks for valid age", {
   expect_identical(test_age(tempdata, "age", "noresponse"), -4)
 })
 ###############################################################################
-context("testing gender")
 test_that("test for gender checks for correct gender", {
   x <- c("F", "M", "m", "M")
   y <- c(1, 2, 3, 4)
@@ -181,8 +175,8 @@ test_that("test for gender checks for correct gender", {
   expect_identical(test_gender(tempdata, c("f", "m", 99), "gender", 99), 0)
   colnames(tempdata) <- c("name", "age")
   expect_error(test_gender(tempdata, c("f", "m", 99), "sex", 99),
-    "Column name does not exist",
-    fixed = TRUE)
+               "Column name does not exist",
+               fixed = TRUE)
   colnames(tempdata) <- c("name", "sex")
   expect_identical(test_gender(tempdata, c(1, 2), "sex", 99), -1)
 
@@ -201,16 +195,15 @@ test_that("test for gender checks for correct gender", {
     "gender", 99), 0)
 })
 # ############################################################################
-context("testing get value from codes")
 test_that("test  get value from codes", {
   data <- data.frame("sex" = c(1, 2, 2, 1, 1),
-   "Name" = c("John", "Dora", "Dora", "John", "John"))
+                     "Name" = c("John", "Dora", "Dora", "John", "John"))
   list_codes_values <- list(c(1, 2), c("F", "M"))
   ans <- get_value_from_codes(data, column = "sex", nrcode = NA,
-  list_codes_values)
+                              list_codes_values)
   expect_equal(ans, c("F", "M", "M", "F", "F"))
   expect_error(get_value_from_codes(data, column = NULL, nrcode = NA,
-                       list_codes_values))
+                                    list_codes_values))
   expect_error(get_value_from_codes(data, column = NA, nrcode = NA,
                                     list_codes_values))
   expect_error(get_value_from_codes(data, column = "sex", nrcode = NA,
@@ -219,21 +212,20 @@ test_that("test  get value from codes", {
                                     list_codes_values))
 
   data <- data.frame("sex" = c(1, 2, 3, 1, 2),
-                    "Name" = c("John", "Dora", "Dora", "John", "John"))
+                     "Name" = c("John", "Dora", "Dora", "John", "John"))
   list_codes_values <- list(c(1, 2, 3), c("F", "M", "Other"))
   ans <- get_value_from_codes(data, column = "sex", nrcode = NA,
-                                     list_codes_values)
+                              list_codes_values)
   expect_equal(ans, c("F", "M", "Other", "F", "M"))
 
   data <- data.frame("sex" = c(1, 2, 3, 1, NA),
-                    "Name" = c("John", "Dora", "Dora", "John", "John"))
+                     "Name" = c("John", "Dora", "Dora", "John", "John"))
   list_codes_values <- list(c(1, 2, 3), c("F", "M", "Other"))
   ans <- get_value_from_codes(data, column = "sex", nrcode = NA,
                               list_codes_values)
   expect_equal(ans, c("F", "M", "Other", "F", NA))
 })
 # ############################################################################
-context("testing column contents")
 test_that("test column contents", {
   x <- c("f", "m", "m", "m")
   y <- c(1, 2, 3, 4)
@@ -248,8 +240,8 @@ test_that("test column contents", {
                                         99), 0)
   colnames(tempdata) <- c("name", "age")
   expect_error(test_column_contents(tempdata, "sex", c("f", "M"), 99),
-    "Column name does not exist",
-    fixed = TRUE)
+               "Column name does not exist",
+               fixed = TRUE)
   x <- c(1, 2, 3, 4, 1, 3, 99)
   y <- c(1, 2, 3, 4, 5, 6, 7)
   tempdata <- as.data.frame(cbind(y, x))
@@ -261,7 +253,6 @@ test_that("test column contents", {
     tempdata, "level", c(1, 2, 3), 99), -2)
 })
 # # ############################################################################
-context("testing the column number for column name")
 test_that("test for sex checks for correct gender", {
   x <- c("f", "female", "m", "male")
   y <- c(1, 2, 3, 4)
@@ -273,14 +264,13 @@ test_that("test for sex checks for correct gender", {
   tempdata <- as.data.frame(cbind(y, x))
   colnames(tempdata) <- c("name", "gender")
   expect_error(get_columnno_fornames(tempdata, "sex"),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
   colnames(tempdata) <- c("name", "age")
   expect_equal(get_columnno_fornames(tempdata, "age"), 2)
 })
 # ############################################################################
-context("testing numeric column")
 test_that("test for numeric values in a specific column", {
   x <- c(0, 11, 78, NA)
   y <- c(1, 2, 3, 4)
@@ -306,13 +296,12 @@ test_that("test for numeric values in a specific column", {
 
   colnames(tempdata) <- c("name", "sex")
   expect_error(test_data_numeric("dose", tempdata, -99, 0, 200),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
 })
 
 # # # ########################################################################
-context("testing numeric column")
 test_that("test for numeric values in a column but with no range given", {
   x <- c(0, 11, 78, 120)
   y <- c(1, 2, 3, 4)
@@ -331,12 +320,11 @@ test_that("test for numeric values in a column but with no range given", {
   expect_identical(test_data_numeric_norange("dose", tempdata, -99), -2)
   colnames(tempdata) <- c("name", "sex")
   expect_error(test_data_numeric_norange("dose", tempdata, -99),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
 })
 # ############################################################################
-context("testing string column with restriction on allowed entries")
 test_that("test for string values in a specific column", {
   x <- c("F", "M", "cvb", "sheeja")
   y <- c(1, 2, 3, 4)
@@ -372,7 +360,6 @@ test_that("test for string values in a specific column", {
   ), -5)
 })
 # # ###########################################################################
-context("testing string column")
 test_that("test for string values in a specific column", {
   x <- c("F", "M", "cvb", "sheeja")
   y <- c(1, 2, 3, 4)
@@ -397,12 +384,11 @@ test_that("test for string values in a specific column", {
   expect_identical(test_data_string(tempdata, "name", -99), -2)
   colnames(tempdata) <- c("num", "sex")
   expect_error(test_data_string(tempdata, "name", -99),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
 })
 # ############################################################################
-context("testing part of columnmames")
 test_that("testing part of columnmames", {
   x <- c("F", "M", "cvb", "sheeja")
   y <- c(1, 2, 3, 4)
@@ -416,7 +402,6 @@ test_that("testing part of columnmames", {
   expect_equal(get_colno_pattern_colname("num", colnames(tempdata)), c(1, 2))
 })
 # # ##########################################################################
-context("testing descriptive statistics")
 test_that("testing descriptive statistics", {
   x <- c(0, 11, 78, 160)
   y <- c(1, 2, 3, 4)
@@ -432,9 +417,8 @@ test_that("testing descriptive statistics", {
   )
   rownames(results) <- "age"
   expect_equal(descriptive_stats_col_excl_nrcode(tempdata, "age", NA), results)
- })
+})
 
-context("testing descriptive statistics")
 test_that("testing descriptive statistics", {
   x <- c(0, 11, 78, 160)
   y <- c(1, 2, 3, 4)
@@ -453,7 +437,7 @@ test_that("testing descriptive statistics", {
   expect_equal(descriptive_stats_col_excl_nrcode(tempdata, "age", 0), results,
                tolerance = 0.001)
 })
-context("testing descriptive statistics")
+
 test_that("testing descriptive statistics", {
   x <- c(0, NA, 78, 160)
   y <- c(1, 2, 3, 4)
@@ -469,33 +453,32 @@ test_that("testing descriptive statistics", {
   )
   rownames(results) <- "age"
   expect_equal(descriptive_stats_col_excl_nrcode(tempdata, "age", NA),
-    results)
+               results)
 })
 
-context("testing descriptive statistics")
 test_that("testing descriptive statistics", {
   x <- c(0, NA, "dd", 160)
   y <- c(1, 2, 3, 4)
   tempdata <- as.data.frame(cbind(y, x))
   colnames(tempdata) <- c("name", "age")
   expect_error(descriptive_stats_col_excl_nrcode(tempdata, "age", NA),
-    "Error - column contents not numeric",
-    fixed = TRUE
+               "Error - column contents not numeric",
+               fixed = TRUE
   )
 })
-context("testing descriptive statistics")
+
 test_that("testing descriptive statistics", {
   x <- c(0, 11, 78, 160)
   y <- c(1, 2, 3, 4)
   tempdata <- as.data.frame(cbind(y, x))
   colnames(tempdata) <- c("name", "dose")
   expect_error(descriptive_stats_col_excl_nrcode(tempdata, "age", NA),
-    "Error - no column or column name different",
-    fixed = TRUE
+               "Error - no column or column name different",
+               fixed = TRUE
   )
 })
 # ############################################################################
-context("testing keep required variables")
+
 test_that("testing keep required variables", {
   the_data <- data.frame("Age" = c(21, 15), "sex" = c("m", "f"))
   ans <- keep_required_columns("Age", the_data)
@@ -508,36 +491,35 @@ test_that("testing keep required variables", {
   expect_error(keep_required_columns(NULL, the_data))
 })
 
-# ############################################################################
-context("testing mode function")
+# ####################################
+
 test_that("testing mode function", {
   x <- c(0, 11, 78, 160)
   expect_equal(get_mode_from_vector(x), 0)
 })
-context("testing mode function")
+
 test_that("testing mode function", {
   x <- c(0, "f", 78, 160)
   expect_identical(get_mode_from_vector(x), -1)
 })
-context("testing mode function")
+
 test_that("testing mode function", {
   x <- c(78, NA, 78, 78)
   expect_equal(get_mode_from_vector(x), 78)
 })
-context("testing mode function")
+
 test_that("testing mode function", {
   x <- c(78, "NA", 78, 78)
   expect_identical(get_mode_from_vector(x), -1)
 })
 # ############################################################################
-context("testing column number from pattern")
+
 test_that("testing number from pattern", {
   expect_equal(check_col_pattern_colname("dd", "female_age"), FALSE)
   expect_equal(check_col_pattern_colname("age", "female_age"), TRUE)
   expect_equal(check_col_pattern_colname(12, "12age"), TRUE)
 })
 # ############################################################################
-context("testing column existence")
 test_that("testing column existence", {
   x <- c(0, NA, "dd", 160)
   y <- c(1, 2, 3, 4)
@@ -545,7 +527,7 @@ test_that("testing column existence", {
   colnames(tempdata) <- c("name", "age")
   expect_equal(check_column_exists("age", tempdata), 0)
 })
-context("testing column existence")
+
 test_that("testing column existence", {
   x <- c(0, NA, "dd", 160)
   y <- c(1, 2, 3, 4)
@@ -554,7 +536,7 @@ test_that("testing column existence", {
   expect_equal(check_column_exists("age", tempdata), -1)
 })
 # ############################################################################
-context("testing column existence")
+
 test_that("testing column existence", {
   x <- c(0, NA, "dd", 160)
   y <- c(1, 2, 3, 4)
@@ -562,7 +544,7 @@ test_that("testing column existence", {
   colnames(tempdata) <- c("name", "age")
   expect_equal(check_column_exists("age", tempdata), 0)
 })
-context("testing column existence")
+
 test_that("testing column existence", {
   x <- c(0, NA, "dd", 160)
   y <- c(1, 2, 3, 4)
@@ -571,7 +553,6 @@ test_that("testing column existence", {
   expect_equal(check_column_exists("age", tempdata), -1)
 })
 # ############################################################################
-context("testing returning a subgroup with NA")
 test_that("testing returning a subgroup with NA", {
   x <- c(0, 11, 78, 160)
   y1 <- c("f", "m", "f", NA)
@@ -589,7 +570,6 @@ test_that("testing returning a subgroup with NA", {
   expect_error(return_subgroup_withNA(tempdata, "gender", "f"))
 })
 # ############################################################################
-context("testing returning a subgroup omitting NA")
 test_that("testing returning a subgroup omitting NA", {
   x <- c(0, 11, 78, 160)
   y1 <- c("f", "m", "f", "m")
@@ -599,7 +579,6 @@ test_that("testing returning a subgroup omitting NA", {
   subgp <- tempdata[tempdata$gender == "f" & !is.na(tempdata$gender), ]
   expect_equal(return_subgroup_omitna(tempdata, "gender", "f"), subgp)
 })
-context("testing returning a subgroup omitting NA")
 test_that("testing returning a subgroup omitting NA", {
   x <- c(0, 11, 78, 160)
   y1 <- c("f", NA, "f", "m")
@@ -609,7 +588,6 @@ test_that("testing returning a subgroup omitting NA", {
   subgp <- tempdata[tempdata$gender == "f" & !is.na(tempdata$gender), ]
   expect_equal(return_subgroup_omitna(tempdata, "gender", "f"), subgp)
 })
-context("testing returning a subgroup omitting NA")
 test_that("testing returning a subgroup omitting NA", {
   x <- c(0, 11, 78, 160)
   y1 <- c("f", NA, "f", "m")
@@ -617,12 +595,11 @@ test_that("testing returning a subgroup omitting NA", {
   tempdata <- as.data.frame(cbind(y2, y1, x))
   colnames(tempdata) <- c("num", "desc", "mark")
   expect_error(return_subgroup_omitna(tempdata, "gender", "f"),
-    "Data does not contain the column with the specfied column name",
-    fixed = TRUE
+               "Data does not contain the column with the specfied column name",
+               fixed = TRUE
   )
 })
 # ############################################################################
-context("testing representing categorical data while excluding missing data")
 test_that("testing represnting categorical data  excluding missing data", {
   x <- c(0, 11, 78, 160)
   y1 <- c("f", "m", "f", "m")
@@ -637,8 +614,8 @@ test_that("testing represnting categorical data  excluding missing data", {
   colnames(tempdata) <- c("num", "a", "mark")
   expect_error(represent_categorical_data_exclude_missing(tempdata, "gender",
                                                           NA),
-    "Data does not contain the column with the specfied column name",
-    fixed = TRUE
+               "Data does not contain the column with the specfied column name",
+               fixed = TRUE
   )
 
   x <- c(0, 11, 78, 10)
@@ -665,7 +642,6 @@ test_that("testing represnting categorical data  excluding missing data", {
 })
 
 # ############################################################################
-context("testing representing categorical data while including missing data")
 test_that("testing representing categorical data including missing data", {
   x <- c(0, 11, 78, 160, NA)
   y1 <- c("f", "m", "f", "m", NA)
@@ -683,22 +659,20 @@ test_that("testing representing categorical data including missing data", {
                                                           NA),
                "Data does not contain the column with the specfied column name",
                fixed = TRUE)
- })
+})
 # ############################################################################
-context("testing representing categorical data from subgroup")
 test_that("testing representing categorical data from subgroup", {
   this.df <- data.frame(c(11, 78, 22), c("m", "f", "f"), c(1, 2, 2),
                         stringsAsFactors = FALSE)
   colnames(this.df) <- c("mark", "gender", "group")
   ans <- represent_numerical_data_forsubgroups(this.df, "group",
-                                                 "mark", NA)
+                                               "mark", NA)
   expect_error(represent_numerical_data_forsubgroups(this.df, NULL,
-                                        "mark", NA))
+                                                     "mark", NA))
   expect_error(represent_numerical_data_forsubgroups(this.df, "group",
                                                      "xx", NA))
 })
 # ############################################################################
-context("testing representing categorical data from subgroup")
 test_that("testing representing categorical data from subgroup", {
   this.df <- data.frame(c(11, 78, 22), c("m", "f", "f"), c(1, 2, 2),
                         stringsAsFactors = FALSE)
@@ -719,7 +693,7 @@ test_that("testing representing categorical data from subgroup", {
                         c(1, 1, 2, 2, 2), stringsAsFactors = FALSE)
   colnames(this.df) <- c("mark", "gender", "group")
   ans <- represent_categorical_data_forsubgroups(this.df, "group",
-                                                       "gender", NA)
+                                                 "gender", NA)
 
   this.df <- data.frame(c(11, 78, 22, 22, 33), c("m", "f", "f", "f", NA),
                         c(1, 1, 2, 2, 2), stringsAsFactors = FALSE)
@@ -728,7 +702,6 @@ test_that("testing representing categorical data from subgroup", {
                                                  "gender", NA)
 })
 # ############################################################################
-context("testing cohens d")
 test_that("testing cohens d", {
   x <- c(0, 11, 78, 160)
   y <- c(1, 2, 3, 4)
@@ -740,15 +713,14 @@ test_that("testing cohens d", {
   expect_equal(res, ans)
   x <- c(0, 11, 78, NA)
   expect_error(cohensd(x, y), "Vector contains atleast one NA or string",
-    fixed = TRUE
+               fixed = TRUE
   )
   x <- c(0, 11, 78, "sh")
   expect_error(cohensd(x, y), "Vector contains atleast one NA or string",
-    fixed = TRUE
+               fixed = TRUE
   )
 })
 # #############################################################################
-context("testing standard error of mean function")
 test_that("testing standard error of mean function", {
   x <- c(0, 11, 78, 160)
   semhere <- sd(x) / sqrt(length(x))
@@ -760,7 +732,6 @@ test_that("testing standard error of mean function", {
   expect_equal(res, semhere)
 })
 ###############################################################################
-context("testing age calculated from date of birth")
 test_that("testing age calculated from date of birth", {
   x <- c("1987-05-28", "1987-06-18", "0", "1987-07-09")
   y <- c(1, 2, 3, 4)
@@ -771,16 +742,16 @@ test_that("testing age calculated from date of birth", {
   ag3 <- eeptools::age_calc(as.Date("1987-07-09"), units = "years")
   ages <- c(ag1, ag2, 0, ag3)
   mod_data <- calculate_age_from_dob(tempdata, "dob", NULL, "ymd", 0)$age
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
   mod_data <- calculate_age_from_dob(tempdata, "dob", NA, "ymd", 0)$age
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("1770-05-28", "1987-06-18", "0", "1987-07-09")
   y <- c(1, 2, 3, 4)
   tempdata <- data.frame(cbind(y, x), stringsAsFactors = FALSE)
   colnames(tempdata) <- c("name", "dob")
   expect_error(calculate_age_from_dob(tempdata, "dob",
-                                                  NULL, "ymd", 0))
+                                      NULL, "ymd", 0))
 
   x <- c("1947-05-28", "1957-06-18", "0", "1967-07-09")
   y <- c(1, 2, 3, 4)
@@ -789,7 +760,7 @@ test_that("testing age calculated from date of birth", {
   colnames(tempdata) <- c("name", "dob", "start")
   ages <- c(43, 33, 0, 23)
   mod_data <- calculate_age_from_dob(tempdata, "dob", "start", "ymd", 0)$age
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("1987-05-28", "1987-06-18", "0", "1987-07-09")
   y <- c(1, 2, 3, 4)
@@ -800,7 +771,7 @@ test_that("testing age calculated from date of birth", {
   ag3 <- eeptools::age_calc(as.Date("1987-07-09"), units = "years")
   ages <- c(ag1, ag2, 0, ag3)
   mod_data <- calculate_age_from_dob(tempdata, "dob", NULL, "ymd", 0)$age
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
 
   x <- c("1287-05-28", "1987-06-18", NA, "1987-07-09")
@@ -816,7 +787,7 @@ test_that("testing age calculated from date of birth", {
   mod_data <- calculate_age_from_dob(
     tempdata, "dob", NULL, "ymd", NA)$age
   ages <- c(ag1, ag2, NA, ag3)
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("1987-05-28", "1987-06-18", NA, "1987-07-09")
   y <- c(1, 2, 3, 4)
@@ -825,7 +796,7 @@ test_that("testing age calculated from date of birth", {
   mod_data <- calculate_age_from_dob(tempdata, "dob", NULL, "ymd", NA
   )$age
   ages <- c(ag1, ag2, NA, ag3)
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("28/05/1987", "18/06/1987", NA, "9/7/1987")
   y <- c(1, 2, 3, 4)
@@ -836,7 +807,7 @@ test_that("testing age calculated from date of birth", {
     "dmy", NA
   )$age
   ages <- c(ag1, ag2, NA, ag3)
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("05/28/1987", "06/18/1987", NA, "7/9/1987")
   y <- c(1, 2, 3, 4)
@@ -847,7 +818,7 @@ test_that("testing age calculated from date of birth", {
     "mdy", NA
   )$age
   ages <- c(ag1, ag2, NA, ag3)
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
 
   x <- c("1997-05-28", "1987-06-18", NA, "2015-07-09")
@@ -859,23 +830,22 @@ test_that("testing age calculated from date of birth", {
   ag3 <- eeptools::age_calc(as.Date("2015-07-09"), units = "years")
   ages <- c(ag1, ag2, NA, ag3)
   mod_data <- calculate_age_from_dob(tempdata, "dob", NULL, "ymd", NA)$age
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   x <- c("1997 May 28", "1987-June-18", NA, "2015/July/09")
   y <- c(1, 2, 3, 4)
   tempdata <- as.data.frame(cbind(y, x), stringsAsFactors = FALSE)
   colnames(tempdata) <- c("name", "dob")
   mod_data <- calculate_age_from_dob(tempdata, "dob", NULL, "ymd", NA)$age
-  expect_equivalent(ages, mod_data, tolerance = 0.001)
+  expect_equal(ages, mod_data, tolerance = 0.001)
 
   colnames(tempdata) <- c("name", "date")
   expect_error(calculate_age_from_dob(tempdata, "dob", NULL, "ymd", NA),
-    "Column name does not exist",
-    fixed = TRUE
+               "Column name does not exist",
+               fixed = TRUE
   )
 })
 # ############################################################################
-context("testing the unique contents of a column")
 test_that("testing the unique contents of a column", {
   x <- c("f", "m", "m", "m")
   y <- c(1, 2, 3, 4)
@@ -884,11 +854,10 @@ test_that("testing the unique contents of a column", {
   expect_identical(get_contents_cols(tempdata, "sex"), c("f", "m"))
   expect_identical(get_contents_cols(tempdata, "number"), c(1, 2, 3, 4))
   expect_error(get_contents_cols(tempdata, "gender"),
-            "Data does not contain the column with the specfied column name",
-            fixed = TRUE)
+               "Data does not contain the column with the specfied column name",
+               fixed = TRUE)
 })
 # ############################################################################
-context("testing presenting mean and ad after removing NA")
 test_that("testing presenting mean and ad after removing NA", {
   this_data <- data.frame(
     "age" = c(21, 15),
@@ -896,9 +865,8 @@ test_that("testing presenting mean and ad after removing NA", {
   )
   this_res <-  "18 (4.24)"
   expect_equal(present_mean_sd_rmna_text(this_data, "age", NA), this_res)
- })
+})
 # ############################################################################
-context("testing representing categorical data")
 test_that("testing representing categorical data", {
   this.df <- data.frame(c(11, 78), c("m", "f"), stringsAsFactors = FALSE)
   colnames(this.df) <- c("mark", "gender")
@@ -906,7 +874,6 @@ test_that("testing representing categorical data", {
   expect_equal(result[1], 1)
 })
 # ############################################################################
-context("testing representing categorical text data")
 test_that("testing representing categorical text data", {
 
   df <- data.frame(c(11, 78), c("m", "f"), stringsAsFactors = FALSE)
@@ -915,7 +882,6 @@ test_that("testing representing categorical text data", {
   expect_equal(unname(result[1]), "1 (50)")
 })
 # ############################################################################
-context("testing convert date numeric form to std form")
 test_that("testingconvert date numeric form to std form", {
   result <- convert_date_numeric_stdform(c("01/01/2000", "02/02/2002"),
                                          c(1, 2), "dmy")
@@ -923,7 +889,6 @@ test_that("testingconvert date numeric form to std form", {
 })
 
 # ############################################################################
-context("testing convert date string form to std form")
 test_that("testingconvert date sting form to std form", {
   result <- convert_date_string_stdform("Feb-1-2020", "mdy")
   expect_equal(unname(result[1]), "2020-2-1")
@@ -970,11 +935,11 @@ test_that("testingconvert date sting form to std form", {
   expect_error(convert_date_string_stdform("Feb-12-ss", "mdy"))
 })
 # ############################################################################
-context("testing getting summary from gtsummary")
 test_that("testing getting summary from gtsummary", {
   y <- c(10, 20.4, 32, 43)
   x <- c("f", "m", "m", "m")
   tempdata <- data.frame(y, x, stringsAsFactors = FALSE)
+
   colnames(tempdata) <- c("mark", "sex")
   summary_tempdata <- get_summary_gtsummary(tempdata, c("mark", "sex"),
                                             byvar = NULL)
@@ -982,22 +947,21 @@ test_that("testing getting summary from gtsummary", {
   my_data <- gtsummary::trial
 
   this <- get_summary_gtsummary(my_data, selectvar = c("trt", "age", "marker", "response"),
-          byvar = "trt")
+                                byvar = "trt")
   expect_equal(this$N, 200)
 
 
   expect_error(get_summary_gtsummary(my_data, selectvar = c("age", "grade"),
-                        byvar = "trt", label = grade ~ "Tumor Grade"))
+                                     byvar = "trt", label = grade ~ "Tumor Grade"))
 
   expect_error(get_summary_gtsummary(NULL, selectvar = c("trt", "age", "grade"),
-                      byvar = "trt", label = grade ~ "Tumor Grade"))
+                                     byvar = "trt", label = grade ~ "Tumor Grade"))
   expect_error(get_summary_gtsummary(my_data, selectvar = NULL,
-                        byvar = "trt", label = grade ~ "Tumor Grade"))
+                                     byvar = "trt", label = grade ~ "Tumor Grade"))
   expect_error(get_summary_gtsummary(my_data, selectvar = NA,
                                      byvar = "trt", label = grade ~ "Tumor Grade"))
 })
 # ############################################################################
-context("testing for returning the longitudinal summary")
 test_that("testing for returning the longitudinal summary", {
   test_data <- as.data.frame(cbind(c(1,2,3,4,5), c(20,40,60,80,100),
                                    c("F", "F", "M", "M", "F")))
